package _VisualDVM.Visual.Interface;
import Common.Visual.VisualizerForm;
public interface VariantsWindow extends VisualizerForm, FormWithSplitters {
    void ShowProjectDistribution();
    void ShowNoProjectDistribution();
    void ShowVariantsFilterButtons();
    void ShowVariantsFilter();
    void ShowNoVariantsFilter();
    void ShowTotalVariantsCount();
    void ShowFilteredVariantsCount();
    void ShowCheckedVariantsCount();
    void ShowNoCheckedVariantsCount();
    void ShowNoFilteredVariantsCount();
    void ShowNoTotalVariantsCount();
    void ShowVariants();
    void RefreshVariants();
    void ShowNoVariants();
}
